import { BigQuery, BigQueryOptions, Dataset, Job, QueryRowsResponse } from '@google-cloud/bigquery';
import { Bucket, Storage } from '@google-cloud/storage';
import { BaseDriver, DownloadTableCSVData, DriverInterface, QueryOptions, StreamTableData } from '@cubejs-backend/base-driver';
import { Required } from '@cubejs-backend/shared';
import { Query } from '@google-cloud/bigquery/build/src/bigquery';
interface BigQueryDriverOptions extends BigQueryOptions {
    readOnly?: boolean;
    projectId?: string;
    keyFilename?: string;
    exportBucket?: string;
    location?: string;
    pollTimeout?: number;
    pollMaxInterval?: number;
    maxPoolSize?: number;
}
declare type BigQueryDriverOptionsInitialized = Required<BigQueryDriverOptions, 'pollTimeout' | 'pollMaxInterval'>;
export declare class BigQueryDriver extends BaseDriver implements DriverInterface {
    /**
     * Returns default concurrency value.
     */
    static getDefaultConcurrency(): number;
    protected readonly options: BigQueryDriverOptionsInitialized;
    protected readonly bigquery: BigQuery;
    protected readonly storage: Storage | null;
    protected readonly bucket: Bucket | null;
    constructor(config?: BigQueryDriverOptions);
    static driverEnvVariables(): string[];
    testConnection(): Promise<void>;
    readOnly(): boolean;
    query<R = unknown>(query: string, values: unknown[], options?: QueryOptions): Promise<R[]>;
    protected loadTablesForDataset(dataset: Dataset): Promise<{}>;
    tablesSchema(): Promise<{}>;
    getTablesQuery(schemaName: string): Promise<{
        table_name: string | undefined;
    }[]>;
    tableColumnTypes(table: string): Promise<any>;
    createSchemaIfNotExists(schemaName: string): Promise<import("@google-cloud/common/build/src/service-object").GetResponse<any>>;
    isUnloadSupported(): Promise<boolean>;
    stream(query: string, values: unknown[]): Promise<StreamTableData>;
    unload(table: string): Promise<DownloadTableCSVData>;
    loadPreAggregationIntoTable(preAggregationTableName: string, loadSql: string, params: any, options: any): Promise<any>;
    protected awaitForJobStatus(job: Job, options: any, withResults: boolean): Promise<true | [any[]] | [any[], Query | null, import("@google-cloud/bigquery/build/src/types").default.IGetQueryResultsResponse] | null>;
    protected runQueryJob<T = QueryRowsResponse>(bigQueryQuery: Query, options: any, withResults?: boolean): Promise<T>;
    protected waitForJobResult(job: Job, options: any, withResults: boolean): Promise<true | [any[]] | [any[], Query | null, import("@google-cloud/bigquery/build/src/types").default.IGetQueryResultsResponse]>;
    quoteIdentifier(identifier: string): string;
}
export {};
//# sourceMappingURL=BigQueryDriver.d.ts.map